| Title: | 'Rapidxml' C++ Header Files |
|---|---|
| Description: | Provides XML parsing capability through the 'Rapidxml' 'C++' header-only library. |
| Authors: | David Cooley [aut, cre], Marcin Kalicinski [ctb] (Author of c++ rapidxml library) |
| Maintainer: | David Cooley <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-05-17 07:33:15 UTC |
| Source: | https://github.com/cran/rapidxmlr |
Provides XML parsing capability through the 'Rapidxml' 'C++' header-only library.
Maintainer: David Cooley [email protected]
Other contributors:
Marcin Kalicinski (Author of c++ rapidxml library) [contributor]
## Not run: # Include a dependency to rapidxmlr inside a cpp file // [[Rcpp::depends(rapidxmlr)]] include <Rcpp.h> ## End(Not run)## Not run: # Include a dependency to rapidxmlr inside a cpp file // [[Rcpp::depends(rapidxmlr)]] include <Rcpp.h> ## End(Not run)